#
# spec file for package python-gobject
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
# Define these before the call of python_subpackages
%define introspection_real_package  %(rpm -q --qf '%%{NAME}' -f $(readlink %{_libdir}/libgirepository-2.0.so -f))
%define cairo_real_package %(rpm -q --qf '%%{NAME}' --whatprovides cairo)
# Don't BuildRequire pkgconfig(gdk-3.0) to find the real package for libgdk-3!
# It produces a dependency cycle: avahi - gtk3-devel - python-dbus-python
#%%define gdk_real_package %%(rpm -q --qf '%%{NAME}' -f $(readlink %%{_libdir}/libgdk-3.so -f))
# This figures in an error message
%global __requires_exclude typelib\\(%%namespaces\\)
%global __requires_exclude_from ^%{_libdir}/python.*/site-packages/gi/__init__.py$
%define _name   pygobject
%define glib_version 2.80.0
%define gi_version 1.64.0
%define pycairo_version 1.16.0
%define libffi_version 3.0
%{?sle15_python_module_pythons}
Name:           python-gobject
VCS: https://src.suse.de/SLFO-pool/python-gobject?trackingbranch=main#40dec4f641f6986bbf84302719981b6a6591b985df94c6e85551ded429c5f3de
Version:        3.52.3
Release:        160000.3.2
Summary:        Python bindings for GObject
License:        LGPL-2.1-or-later
Group:          Development/Languages/Python
URL:            https://wiki.gnome.org/Projects/PyGObject/
Source0:        %{_name}-%{version}.tar.zst
Source1:        pythoncapi-compat-vendored.tar.zst

BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module meson-python}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pycairo >= %{pycairo_version}}
BuildRequires:  %{python_module pycairo-devel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cairo-gobject)
# build cycle!
# BuildRequires:  pkgconfig(gdk-3.0) >= 2.38.0
BuildRequires:  pkgconfig(gio-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(girepository-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(glib-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(gobject-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= %{gi_version}
BuildRequires:  pkgconfig(libffi) >= %{libffi_version}
# Trigger an automatic installation of python(2|3.*)-gobject when python and libgirepository are installed.
Supplements:    (python and %{introspection_real_package})
Provides:       python-pygobject = %{version}
%python_subpackages

%description
Pygobjects is an extension module for python that gives you access to
GLib's GObjects.

%package Gdk
Summary:        Python bindings for GObject/Gdk
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       %{name}-cairo = %{version}
# See above
#Supplements:    (python-gobject and %{gdk_real_package})

%description Gdk
Pygobjects is an extension module for python that gives you access to
GLib's GObjects.

This package contains the Python Gdk bindings for GObject.

%package cairo
Summary:        Python bindings for GObject/Cairo
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Supplements:    (python-gobject and %{cairo_real_package})
Requires:       python-cairo

%description cairo
Pygobjects is an extension module for python that gives you access to
GLib's GObjects.

This package contains the Python Cairo bindings for GObject.

%package devel
Summary:        Metapackage to pull in all of python-gobject's packages
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       %{name}-Gdk = %{version}
Requires:       %{name}-cairo = %{version}
Requires:       %{name}-common-devel = %{version}
Requires:       python-devel

%description devel
This package contains files required to build wrappers for gobject
addon libraries such as pygtk.

%package -n %{name}-common-devel
Summary:        Shared development files for GObject's Python bindings
Group:          Development/Languages/Python
Requires:       glib2-devel >= %{glib_version}
Requires:       gobject-introspection-devel >= %{gi_version}
Requires:       libffi-devel >= %{libffi_version}
Requires:       pkgconfig(cairo)
Requires:       pkgconfig(cairo-gobject)
Provides:       %{python_module gobject-common-devel = %{version}}

%description -n %{name}-common-devel
This package contains common files required to build wrappers for gobject
addon libraries such as pygtk in both Python2 and Python3.

%prep
%setup -q -n %{_name}-%{version}
%autopatch -p1
pushd subprojects
tar xf %{SOURCE1} --xform=s/pythoncapi-compat-vendored/pythoncapi-compat/
pushd pythoncapi-compat
patch -p1 < ../packagefiles/pythoncapi-compat-meson.diff
popd
popd

%build
export CFLAGS="%{optflags}"
%meson -Dtests=false -Dwheel=false
%meson_build
%pyproject_wheel

%install
%meson_install
%pyproject_install
# Incorrectly installed by a python38-setuptools vendored distutils
# which does not play well with the distro patched python38.
# Later flavors installed the correct files into lib64 as well
if [ "%{_libdir}" != "%{_prefix}/lib" -a -d %{buildroot}%{_prefix}/lib/pkgconfig ]; then
  rm -r  %{buildroot}%{_prefix}/lib/pkgconfig
else
  echo 'Removing %{buildroot}%{_prefix}/lib/pkgconfig is no longer needed.' \
       'Please fix the spec.'
fi

%{python_expand # delete unwanted python scripts and their compiled cache files
# Drop pygtkcompat layer - It's useless and we lack other stuff for it to work
rm -v %{buildroot}%{$python_sitearch}/gi/pygtkcompat.py*
rm -vf %{buildroot}%{$python_sitearch}/gi/__pycache__/pygtkcompat*
rm -vr %{buildroot}%{$python_sitearch}/pygtkcompat/

# Drop GIMarshallingTests - It's test suite remainders that should not be installed
find %{buildroot}%{$python_sitearch} -name GIMarshallingTests* -delete -print
}

find %{buildroot} "(" -name '*.la' -or -name '*.a' ")" -delete
# Nuke a stray metadata file
find %{buildroot}%{python_sitearch}/PyGObject*/ "(" -name 'METADATA' ")" -delete -print

%{?python_compileall}
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%license COPYING
%doc NEWS
%{python_sitearch}/gi/
# Lives in cairo subpackage
%exclude %{python_sitearch}/gi/_gi_cairo*.so
%{python_sitearch}/pygobject-*.dist-info/
# Lives in Gdk subpackage
%exclude %{python_sitearch}/gi/_gtktemplate.py
%exclude %{python_sitearch}/gi/overrides/Gdk.*
%exclude %{python_sitearch}/gi/overrides/GdkPixbuf.py
%exclude %{python_sitearch}/gi/overrides/Gtk.*
%exclude %{python_sitearch}/gi/overrides/Pango.*
%pycache_only %exclude %{python_sitearch}/gi/__pycache__/_gtktemplate*
%pycache_only %exclude %{python_sitearch}/gi/overrides/__pycache__/Gdk.*
%pycache_only %exclude %{python_sitearch}/gi/overrides/__pycache__/GdkPixbuf.*
%pycache_only %exclude %{python_sitearch}/gi/overrides/__pycache__/Gtk.*
%pycache_only %exclude %{python_sitearch}/gi/overrides/__pycache__/Pango.*

%files %{python_files Gdk}
%{python_sitearch}/gi/_gtktemplate.py
%{python_sitearch}/gi/overrides/Gdk.*
%{python_sitearch}/gi/overrides/GdkPixbuf.py
%{python_sitearch}/gi/overrides/Gtk.*
%{python_sitearch}/gi/overrides/Pango.*
%pycache_only %{python_sitearch}/gi/__pycache__/_gtktemplate*
%pycache_only %{python_sitearch}/gi/overrides/__pycache__/Gdk.*
%pycache_only %{python_sitearch}/gi/overrides/__pycache__/GdkPixbuf.*
%pycache_only %{python_sitearch}/gi/overrides/__pycache__/Gtk.*
%pycache_only %{python_sitearch}/gi/overrides/__pycache__/Pango.*

%files %{python_files cairo}
%{python_sitearch}/gi/_gi_cairo*.so

%files %{python_files devel}
%doc README.rst
%{_includedir}/python%{python_version}/pygobject/

%files -n %{name}-common-devel
%{_includedir}/pygobject-3.0/
%{_libdir}/pkgconfig/pygobject-3.0.pc

%changelog
* Tue Apr  1 2025 suse-beta@cboltz.de
- Re-add BuildRequires pkgconfig(gobject-introspection-1.0) to
  fix "cannot import name GLib, introspection typelib not found"
  error (boo#1240549)
* Sun Mar 16 2025 bjorn.lie@gmail.com
- Update to version 3.52.3:
  + Remove invalid error check for gi_constant_info_get_value.
* Wed Mar 12 2025 dimstar@opensuse.org
- Update to version 3.52.2:
  + Revert to legacy license definition in pyproject.toml.
- Drop pygobject-license.patch: variant of this has been merged
  upstream.
* Mon Mar 10 2025 dimstar@opensuse.org
- Update to version 3.52.1
  + Use `girepository` 2.0 for GIR mappings.
  + Use Python's vectorcall protocol internally.
  + Improved API for asyncio.
  + Deprecation: The pygtkcompat module now throws an exception
    when imported.
  + Method signatures are exposed from PyGObject now.
  + Use gobject-introspection-tests for testing.
  + Convenience API for Gdk.RGBA got GDK 4, similar to GDK 3.
  + Added a [pre-commit](https://pre-commit.com/) configuration.
  + Use standard `enum` module for enums and flags in PyGObject.
  + Added an option to skip automatic initialization of GTK and
    GDK.
  + PyGObject is no longer automatically tested on i386
    architecture.
  + Fixed iterator protocol implementation for properties.
  + Various code and documentation improvements.
- Add pythoncapi-compat as subproject.
- Pass -Dtests=false to meson: disable tests for now, as we do not
  have the submodule for that.
- Pass -Dwheel=false to meson, as we use our own python
  single-spec mechanism to install the python bindings.
- Add pygobject-license.patch: Fix build by not relying on PE-639
  yet.
- Replace pkgconfig(gobject-introspection-1.0) BuildRequires with
  pkgconfig(girepository-2.0): follow upstreams changes.
- Drop pkgconfig(gmodule-2.0) BuildRequires: no longer needed.
* Wed Feb  5 2025 dimstar@opensuse.org
- Update to version 3.51.0:
  + Use `girepository` 2.0 for GIR mappings.
  + Use Python's vectorcall protocol internally.
  + Improved API for asyncio.
  + Deprecation: The pygtkcompat module now throws an exception
    when imported.
  + Method signatures are exposed from PyGObject now.
  + Convenience API for Gdk.RGBA got GDK 4, similar to GDK 3.
  + Use standard `enum` module for enums and flags in PyGObject.
  + Added an option to skip automatic initialization of GTK and
    GDK.
  + Fixed iterator protocol implementation for properties.
  + Various code and documentation improvements.
* Wed Oct 30 2024 i@guoyunhe.me
- Add python-pygobject provides: help packages to eliminate rpmlint
  warnings when comparing requrements.txt vs the packages depdency.
  'pygobject' is the proper upstream name.
* Thu Sep 12 2024 bjorn.lie@gmail.com
- Update to version 3.50.0:
  + tests: Fix event test errors when GTK is not installed
* Fri Sep  6 2024 bjorn.lie@gmail.com
- Update to version 3.49.0:
  + Rename master branch to main
  + Drop support for Python 3.8
  + Add Override for Gio.DataInputStream
  + Treat GParamSpec as any other fundamental type
  + override connection.register_object to prevent an invocation
    object from leaking
  + Various PyPy related fixes
  + bind_property: Accept keyword arguments
  + Various documentation improvements
  + Python2 / GTK2 cleanups
  + asyncio integration with support to await Gio async functions
  + meson: move from .egg-info to .dist-info/METADATA
  + build: fixes for building with gobject-introspection 1.81
- Stop removing executable bits from examples, no longer needed.
* Mon Apr  8 2024 dimstar@opensuse.org
- Update to version 3.48.2:
  + Fix support for fundamental (primitive) types, such as
    Gst.Bitmask.
* Mon Mar 11 2024 dimstar@opensuse.org
- Update to version 3.48.1:
  + Fix installation with pip failing in some environments with
    ModuleNotFoundError in g-ir-scanner.
* Sat Mar  9 2024 dimstar@opensuse.org
- Update to version 3.48.0:
  + test: fix some tests on macOS.
  + docs: some dark mode fixes.
* Tue Feb 13 2024 dimstar@opensuse.org
- Update to version 3.47.0:
  + Drop setuptools in favor of meson-python.
  + Fundamental type support.
  + Fundamental type support for GValues.
  + pygi-convert.sh: migrate FILE_CHOOSER_CONFIRMATION_*.
  + gimodule, cairo: Use multi-phase initialization as per PEP-489.
  + Deprecate classes in gi.option module.
  + Deprecate pygtkcompat.
  + Add support for (optional) nullable GErrors.
  + Fix CssProvider not valid in GTK2.
  + Fix double free if array item cannot be marshalled to Python.
  + Raise exception if a callback property is encountered.
  + build: Fix pycairo detection "script" for Windows.
  + Replace deprecated ``pkgutil.find_loader`` call.
  + Avoid segfault on property access for incompletely initialized
    objects.
  + pygenum: When getting a member instance, use correct key for
    the lookup.
  + Project / Development / CI:
  - Remove pborelli from the maintainer list.
  - Add Arjan Molenaar to maintainers.
  - Remove runtests script.
* Sun Sep 10 2023 luc14n0@opensuse.org
- Update to version 3.46.0:
  + Add support for Python 3.12.
  + Drop GTK 2 support.
  + Complete the PEP-451 implementation in gi.importer.
  + Replace usage of deprecated FFI closure API.
  + Fix invalid marshalling in some cases for boxed values, for
    example with Gtk.StyleContext.get_property().
  + Consistent setting of enum and flag property.
  + Fix docstring for methods that return an array and have a
    length (out) argument.
  + Overrides:
  - Fix incompatibility for CssProvider.load_from_data() (GTK
    4.10).
  - Allow Gdk.{Color,RGBA} instances to be compared with other
    objects.
  - Add overrides for Gdk.FileList in Gdk-4.0.
  + Updated documentation.
- Add explicit BuildRequires on pkgconfig(libffi). This is looked
  by the build scripts and was already being pulled in by something
  else.
* Sat Jun 10 2023 ecsos@oensuse.org
- Add %%{?sle15_python_module_pythons}: build additional python
  flavors besides the 'default' when building for SLE15.
* Fri Mar 24 2023 bjorn.lie@gmail.com
- Update to version 3.44.1:
  + Fix tests with glib 2.76.x
* Sun Mar 19 2023 bjorn.lie@gmail.com
- Update to version 3.44.0:
  + No changes compared to 3.43.1
* Fri Feb 24 2023 bjorn.lie@gmail.com
- Update to version 3.43.1:
  + Drop support for Python 3.6
  + meson: bump minimum version to 0.53.0 and update subprojects
  + gimodule: fix floating state of python objects created with
    g_object_new
  + Gtk.Template: Accept PathLike objects as a filename
  + info: Show which type/object callables are bound to
  + IntrospectionModule: handle two threads loading type at same
    time
  + Port to Py_TRASHCAN_BEGIN
  + Other cleanups/improvements
* Fri Jul 22 2022 bjorn.lie@gmail.com
- Update to version 3.42.2:
  + Error out instead of crashing when marshaling unsupported
    fundamental types in some cases.
  + Add a workaround for a PyPy 3.9+ bug when threads are used.
  + Fix crashes when marshaling zero terminated arrays for certain
    item types.
  + Fix a crash/refcounting error in case marshaling a hash table
    fails.
  + Make the test suite pass again with PyPy.
  + tests: support running tests with (MSVC) CPython 3.8+ on
    Windows.
  + interface: Fix leak when overriding GInterfaceInfo.
  + setup.py: look up pycairo headers without importing the module
    (helps with building on Windows and MSVC CPython 3.8+).
* Sat Jul 16 2022 code@bnavigator.de
- Work around vendored distutils in setuptools >= 60 incorrectly
  installing pkgconfig files into the wrong libdir
* Thu Jun  9 2022 dimstar@opensuse.org
- Add dependency on python-cairo to python-gobject-cairo: The
  introspection wrapper needs the actual pycairo underneath
  (boo#1179584).
* Thu Apr 21 2022 emilyyrose@gmail.com
- Update to version 3.42.1:
  + Do not error out for unknown scopes.
  + gtk overrides: restore Gtk.ListStore.insert_with_valuesv with
    newer GTK4.
  + gtk overrides: Do not override Treeview.enable_model_drag_xx
    for GTK4.
  + Implement DynamicImporter.find_spec() to silence deprecation
    warning.
  + Some test/CI fixes.
* Mon Sep 20 2021 dimstar@opensuse.org
- Update to version 3.42.0:
  + meson: Bump minimum meson_version to 0.47.0.
  + Expose GObject.Object.run_dispose().
  + docs: document Gtk.Template.
  + dev: Add poetry support.
  + meson: use main branch for glib subproject.
  + Fix some small memory leaks.
* Wed Aug  4 2021 dimstar@opensuse.org
- Adjust BuildRequires for python_module cairo to python-module
  pycairo: the module was renamed 2 years ago.
- Skip build for python2: not supported anymore since 3.38.0.
* Sat Apr 17 2021 dimstar@opensuse.org
- Update to version 3.40.1:
  + Fix tests with glib 2.68.
  + Fix a regression with marshalling partial() objects.
* Fri Mar 19 2021 mgorse@suse.com
- Update to version 3.40.0:
  + GTK 4 compatibility fixes.
  + Python 3.9 and 3.10 compatibility fixes.
  + New minimal dependency requirements.
- Up glib2, gobject-introspection, and cairo required versions.
* Wed Jan 13 2021 code@bnavigator.de
- Recompile python cache files after removal of components, include
  cache files in correct subpackage
- Fix supplements declarations, where possible. Disable for -gdk.
* Wed Jan 13 2021 dimstar@opensuse.org
- Simplify the dependency exclusion from __init__.py to also match
  with multiple python3-flavors.
- Remove exec bit from all *.py files in examples, also
  subdirectories.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + meson: Make the `pycairo` option a feature.
  + gdk overrides: Fix wrapping of scroll events.
  + Add overrides for Gtk.Button set/get_focus_on_click.
* Wed May  6 2020 bjorn.lie@gmail.com
- Update to version 3.36.1:
  + tests: Fix failing tests with pytest 5.4.0+.
  + Gtk: Add override to make sure both
    TreeModelSort.new_with_model and TreeModel.sort_new_with_model
    exist independend of the gtk version.
  + Gtk.Template: Fix initialisation order errors with Widgets
    getting created from C (potentially through other templates).
  + Gtk.Template: Fix errors when calling init_template() multiple
    times.
* Sun Mar  8 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + This will be the last release supporting Python 2.
  + pygobject-object: Avoid checking whether NULL is floating.
  + Avoid various new glib deprecation warnings.
  + Port to g_object_new_with_properties().
  + Drop Python 2 support on Windows.
  + gtk overrides: Drop Menu, MenuItem for Gtk 4.
  + Docs:
  - Update openSUSE instructions.
  - Add Gaphor to Who is Using PyGObject.
  - Remove reference to a fixed bug.
* Fri Jan 31 2020 dimstar@opensuse.org
- Remove %%{python_module gobject-devel = %%{version}} from
  common-devel: Assuming that consumers of the .pc and include
  headers are not really using the python bindings.
* Sat Jan 11 2020 bjorn.lie@gmail.com
- Drop gnome-common Requires from python-gobject-common-devel
  sub-package, no longer needed, nor used since 3.29.1, where the
  BuildRequires was dropped, but the explicit Requires was not
  removed by mistake.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + No changes since 3.33.1.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 3.33.1:
  + Make GLib.Variant.unpack a bit less costly.
  + pygobject: ignore GParameter deprecations.
  + pygobject-object: fix refcount of floating return values.
  + pygi-info: remove some dead code.
* Mon Jun 24 2019 bjorn.lie@gmail.com
- Update to version 3.32.2:
  + Python 3.8b1 compatibility fixes.
  + tests: fix a test error when run under wayland.
  + setup.py: specify python_requires.
* Sat Apr 20 2019 bjorn.lie@gmail.com
- Update to version 3.32.1:
  + tests/gimarshallingtestsextra.c/h: relicense to LGPLv2.1+.
  + meson: add ``tests`` option for disabling tests.
  + meson: tests: pass ``--quiet`` to g-ir-scanner.
  + Fix a crash when marshalling a GError to Python fails.
  + Fix leak of transfer-full/container C arrays.
* Sun Mar 10 2019 bjorn.lie@gmail.com
- Update to version 3.32.0:
  + No changes since 3.31.4.
* Thu Mar  7 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + docs: document GObject.Object.weak_ref().
  + cairo:
  - Add cairo pattern foreign struct support.
  - Add cairo_matrix_t converter to GValue.
* Thu Feb 14 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Speed up destruction of boxed types and
    GObject.Value.set_value() calls. This makes appending to a
    Gtk.TreeModel nearly twice as fast for example.
  + Allow passing None for boolean parameters.
  + meson: Install .egg-info directory to arch'd dir.
  + gtk overrides: raise in case Gtk.Window is instantiated after
    gtk_init failed.
  + gio overrides: Warn when creating various dbus types without a
    constructor.
  + tests:
  - Fix tests with glib 2.59.x.
  - Fix test_atoms failing in some environments.
* Thu Jan  3 2019 bjorn.lie@gmail.com
- Update to version 3.31.2:
  + GLib.Variant.keys: correctly raise TypeError for non-dict
    types.
  + GLib.Variant: implement __bool__ for maybe types.
  + cairo: Fix GValue converters in case of NULL.
  + setup.py: Print an install command hint when pkg-config is
    missing.
  + pygi-info: wrap g_union_info_get_alignment().
* Sun Dec  2 2018 bjorn.lie@gmail.com
- Update to version 3.30.4:
  + gtk overrides: Fix rows getting inserted on the wrong level
    with TreeStore.insert_before/inster_after if parent=None.
* Tue Nov 27 2018 bjorn.lie@gmail.com
- Update to version 3.30.3:
  + GValue: fall back to the custom C marshaller to support
    fundamental types. This makes GValue work with GstFraction.
  + GValue: Work around wrong annotations for GVariant.
  + Fix GObject attribute access during instance init which can
    lead to errors with __getattr__ implementations of subclasses.
    This lead to criticals when instantiating Gio.DBusProxy.
* Mon Nov 12 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + tests: Fix some test with newer glib.
  + overrides: Fix crash when using non-ascii text with
    Gtk.Builder.add_from_string/add_objects_from_string.
  + Various meson/distutils build fixes for MSVC.
  + foreign-cairo: Fix cairo marshalling not using the foreign
    converters in some cases.
  + build: setup.py reproducible build fixes.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fix various crashes on big endian systems.
  + meson: Don't link against libpython on non-Windows systems.
* Sat Sep  1 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Various test suite fixes to get things to pass with Ubuntu
    18.10.
* Fri Aug 17 2018 bjorn.lie@gmail.com
- Update to version 3.29.3:
  + meson:
  - Support building pycairo as a subproject.
  - Declare_dependency for use by potential superprojects.
  - Update glib wrap file.
  - Fix the Python 2 build not not use the system pycairo
    extension when running tests.
  + pygi-convert.sh: Various fixes and updates.
  + Gtk.Template:
  - Fix instantiation error when using the new code with older
    PyGObject.
  - Don't error out when loading a resource that is only
    available in an overlay.
  + Fix various crashes when running against a debug Python 3.7
    build.
  + overrides:
  - Allow calling GObject.Binding.unbind() multiple times with
    GLib 2.58+.
  - Gio.ListStore overrides use splice() when adding/removing
    many items with GLib 2.58+.
  + Work around pylint reporting bogus warnings regarding a missing
    self argument for normal functions.
  + Add override for GdkPixbuf.Pixbuf.new_from_data() to wrap
    new_from_bytes() to work around a use after free.
* Sat Jun  9 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + Gtk.Template: Allow marking children as "internal-child".
  + Gio.Settings: implement __iter__.
  + Release the GIL when emitting a signal.
  + Don't wrap GValue in GValue when creating GValueArray.
  + Don't crash on multiple calls to GObject.Value.__del__.
  + Various fixes.
  + Various fixes/improvements for PyPy.
  + Issues fixed: glgo#GNOME/pygobject#115,
    glgo#GNOME/pygobject#134, glgo#GNOME/pygobject#130,
    glgo#GNOME/pygobject#45, glgo#GNOME/pygobject#200,
    glgo#GNOME/pygobject#29, glgo#GNOME/pygobject#213,
    glgo#GNOME/pygobject#219, glgo#GNOME/pygobject#193.
  + Updated documentation.
* Mon Jun  4 2018 luc14n0@linuxmail.org
- Update to version 3.29.1:
  + Support for `PyPy <https://pypy.org/>`__ and PyPy3.
    (glgo#GNOME/pygobject#180).
  + Cairo: support :class:`cairo.Matrix` conversion.
    (glgo#GNOME/pygobject#16).
  + Speed up repeated closure creation by caching the closure cache
    in the argument cache (glgo#GNOME/pygobject#103).
  + Overrides: Make :meth:`Gtk.ListStore.insert_before`,
    :meth:`Gtk.ListStore.insert_after`, :meth:`Gtk.TreeStore.\
    insert_before` and :meth:`Gtk.TreeStore.insert_after` atomic.
  + Make :class:`GLib.Error` picklable (glgo#GNOME/pygobject#45).
  + Add basic support for template based widgets through
    ``Gtk.Template`` (glgo#GNOME/pygobject#52).
  + Avoid truncating value returned from g_value_info_get_value.
  + Various documentation improvements.
- Drop:
  + gnome-common BuildRequires and autoreconf call, and replace
    configure/make_build/make_install macros with python_build and
    python_install, following upstream drop of Autotools.
  + pycompile-searchpath.patch: it is no longer needed.
* Fri Jun  1 2018 bjorn.lie@gmail.com
- Update to version 3.28.3:
  + Fix Gio.Application leak in case no signal handler is set
    before.
  + Squash critical warning when using array as hash value.
* Tue Mar 27 2018 luc14n0@linuxmail.org
- Update to version 3.28.2:
  + Fix:
  - __str__ return type of Gtk.TreePath with depth == 0
    (glgo#GNOME/pygobject#143);
  - A crash when setting a str property with a value containing
    surrogates (glgo#GNOME/pygobject#169).
  + Tests: Fix a potential crash during tests.
* Sat Mar 17 2018 luc14n0@linuxmail.org
- Update to version 3.28.1:
  + Fix a GValue leak (regression) (glgo#GNOME/pygobject#176).
  + Various fixes for Python 3.7 (glgo#GNOME/pygobject#170).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + GLib.Variant: Fix creation of guchar arrays from bytes.
* Fri Mar  2 2018 luc14n0@linuxmail.org
- Update to version 3.27.5:
  + Re-revert transfer-none boxed copy changes. Now with more fixes
    and tests.
  + Add caching for boxed type lookup and try to avoid the import
    lock.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb 14 2018 dimstar@opensuse.org
- Update to version 3.27.4:
  + tests: Fix tests under Wayland (glgo#GNOME/pygobject#163).
  + tests: Make it possible to use pytest directly.
  + Reverted transfer-none boxed copy changes due to regressions
    in gnome-music (glgo#GNOME/pygobject#164).
* Sat Feb 10 2018 bjorn.lie@gmail.com
- Update to version 3.27.3:
  + Fix a 3.27.2 regression where functions return invalid boxed
    values.
  + tests:
  - Make tests run without Gtk/Gdk installed.
  - Remove dependency on ``localedef``.
  - Require/Use pytest.
* Wed Feb  7 2018 dimstar@opensuse.org
- Update to version 3.27.2:
  + setup.py:
  - Add a "quality" command which is equal to
    "make check.quality".
  - Add a "test" command which is equal to "make check".
  - Install pkg-config and header files.
  - Improve pycairo header lookup with pycairo >=1.16.
  + autotools: "make check.quality" now requires flake8.
  + overrides:
  - Fix ``Gtk.Adjustment.__init__()`` overrides not setting
    "value" sometimes. :issue:`151` :mr:`3`
  - ``GLib.Variant``: add support to create maybe types.
  + Make it possible to resolve ambiguous vmethod names.
    Ambiguities can be resolved by implementing methods named
    "do_$namespaced_base_class_name_$vfunc_name".
  + Fix setting a property installed in Python from C in some
    cases.
  + pygobject-object: fix memory corruption around list of
    closures.
  + Don't copy the boxed if we are the sole owner of the wrapper
    after a closure.
  + Only copy transfer-none boxed values in closures once the
    closure exists. This allows modifying the passed boxed while
    allowing to keep the wrapper around after the closure is done.
- Drop pkgconfig(libffi) BuildRequires: no longer needed.
* Sun Dec 17 2017 luc14n0@linuxmail.org
- Update to version 3.27.1:
  + setup.py:
  - Rework pycairo discovery to not use pkg-config.
  - Remove various classifiers and the download-url which aren't
    accepted by pypi.
  + Add sphinx based documentation (bgo#791448).
  + PKG-INFO: Revert name back to PyGObject.
- Remove the executable bit from example scripts as an extra
  sanity/security measure.
* Sun Dec 10 2017 luc14n0@linuxmail.org
- Update to version 3.27.0:
  + Demo:
  - pep8 fixes.
  - Add new Gtk.FlowBox example (bgo#735918).
  - Use HeaderBar for main app window (bgo#735918).
  + Fix potential:
  - Uninitialized memory access during GC (bgo#786872).
  - Potential overflow when marshalling flags from py interface
    (bgo#786948).
  + configure.ac: Error out in case autoconf-archive isn't
    installed (bgo#784428).
  + Move pygi-convert.sh into tools.
  + Drop:
  - Python 3.3 support (bgo#790787).
  - pygobject-3.0-uninstalled.pc file.
  + Tests:
  - Some more C locale fixes.
  - Make the test suite pass with the C locale.
  + Fixes: bgo#622084, bgo#622084, bgo#731501, bgo#788890,
    bgo#788894, bgo#777719, bgo#786948, bgo#786948, bgo#735918,
    bgo#735918, bgo#790346, bgo#735918, bgo#735918.
- Switch libffi-devel BuildRequires by its pkgconfig module
  counterpart once configure only looks for its module.
- Adopt the use of %%make_build macro instead of raw make command,
  following best practices.
* Sat Oct 28 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Pygobject-object: Fix Python GC collecting a ref cycle too
    early (bgo#731501).
  + Fix potential uninitialized memory access during GC (bgo#786872).
  + Test: revert parts of the previous test as it's broken on
    32 bit builds (bgo#786948).
  + Flags: Add testcase for bug 786948 (bgo#786948).
  + Fix potential overflow when marshalling flags from py interface
    (bgo#786948).
  + to_py_array: Properly handle enum array items (bgo#788890).
  + Closure: Fix unaligned and out-of-bounds access (bgo#788894).
  + Build: Fix not installing .egg-info file (bgo#777719).
- Run spec-cleaner -p to get respectives pkgconfig(*): gio-2.0,
  glib-2.0 and gobject-introspection-1.0.
* Tue Sep 12 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Closure: silence a new compiler warning.
  + Make sure version information passed to require_version is a
    string (bgo#781582).
  + Test fixes.
* Fri Sep  8 2017 jengelh@inai.de
- Update package summaries. Fix RPM groups and do not run fdupes
  across hardlink partitions.
* Sun Jun 18 2017 dimstar@opensuse.org
- Update to version 3.25.1:
  + Bugs fixed: bgo#663068, bgo#667959, bgo#686835, bgo#698548,
    bgo#699440, bgo#707196, bgo#712197, bgo#726484, bgo#730908,
    bgo#735076, bgo#735206, bgo#744690, bgo#746564, bgo#759009,
    bgo#759276, bgo#762176, bgo#769789, bgo#772896, bgo#772949,
    bgo#773394, bgo#773803, bgo#777713, bgo#777719, bgo#780396,
    bgo#780409, bgo#780591, bgo#780652, bgo#780768, bgo#780812.
* Thu May 18 2017 dimstar@opensuse.org
- Once again filter typelib(Gtk) dependency out of python2-gobject:
  it's not possible to use multiple __requires_exclude_from
  statements in the specfile, thus change the filter to be valid
  for python2 and python3 at the same time.
* Wed Apr 19 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + pygi-info: initialize GIArgument before passing it to
    g_constant_info_get_value (bgo#772949).
* Mon Mar 27 2017 toddrme2178@gmail.com
- Switch to single-spec version.
- Add python version-dependent wrapper packages to pull in
  necessary dependencies.
- Include all dependencies in -devel packages.
- Rebase .changes file to include changes in -devel package.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + overrides: Update for Gdk-4.0 and Gtk+-4.0 (bgo#773315,
    bgo#777680).
  + Disable -Werror=missing-prototypes (bgo#777534).
  + Fix new PEP8 errors (bgo#776009).
  + Move pep8/pyflakes tests from 'make check' to
    'make check.quality' (bgo#764087).
  + Handle exception unreffing Variant at exit (bgo#776092).
  + Handle multiple deinit of callable cache (bgo#776092).
- Drop python-gobject-missing-prototypes.patch: fixed upstream.
* Wed Mar 15 2017 toddrme2178@gmail.com
- Provide python2- versions of packages to ease transition to
  python single-spec macros.
* Mon Feb 27 2017 dimstar@opensuse.org
- Move Pango overrides to -Gdk package: the main pygobject package
  is supposed to be installable without a dependency on X
  (boo#1025819).
* Wed Feb 22 2017 dimstar@opensuse.org
- Add python-gobject-missing-prototypes.patch: Disable
  - Werror=missing-prototypes (bgo#777534).
- Add gnome-common BuildRequires and call autoreconf, as above
  patch touches the build system.
* Mon Sep 19 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Version bump only, no changes.
* Sun Sep 11 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Handle nullable filename parameters (bgo#770821).
  + Fix list/hashtable enum <-> hash conversion on 64-bit big
    endian (bgo#770608).
  + Allow passing sockets to io_add_watch on win32 (bgo#766396).
  + Tests: Use dbus-run-session instead of dbus-launch to run tests
    (bgo#770798).
* Thu Aug 25 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Allow installing with pip (bgo#767988).
  + Skip a test with older glib (bgo#740301).
  + Fix a test with Python 3.1/3.2 (bgo#740324).
  + tests: Use places kwarg for assertAlmostEqual (bgo#740337).
  + Print exception if marshalling a signal argument fails
    (bgo#748198).
  + overrides: allow treemodel sequence shorthands (bgo#766580).
  + Remove pygobject-external.h (bgo#767084).
  + Remove pygobject-private.h and rename pygobject.c to
    pygobject-object.c (bgo#767084).
  + Merge pyglib-private.h into pyglib.h (bgo#767084).
  + Remove pygi.h and pygi-private.h (bgo#767084).
* Wed Aug 17 2016 dimstar@opensuse.org
- Do not consider __init__.py for automatic dependency generation:
  this file is filled with large comments section but in fact not
  with dependencies (parsing it happens to add a typelib(Gtk) = 3.0
  dependency).
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 3.21.0:
  + gi: Add require_versions() function (bgo#761141).
  + build: Do not enable code coverage based on lcov (bgo#764075).
* Tue May  3 2016 dimstar@opensuse.org
- Move gi/overrides/keysyms.* also to the -Gdk subpackage: Keysyms
  is mapped to Gdk symbols and is only usable in GUI apps.
* Mon Apr 25 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + test_gerror_novalue: Don't assign the error to a variable
    (bgo#764165).
* Mon Apr 18 2016 dimstar@opensuse.org
- Do not package GIMarshallingTests: it's only used by the test
  suite and is useless on an installed system (the corresponding
  typelibs and libraries are also not installed).
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Wed Apr 13 2016 dimstar@opensuse.org
- Split out a python[3]-gobject-Gdk subpackage: do not forcibly
  pull in the entire X-stack for CLI tools requiring python-gobject
  for dbus bindings for example.
- The new package supplements python-gobject together with libgdk.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + No changes.
* Wed Mar 16 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + No changes.
* Wed Mar  2 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Fix marshaling of GError stored in GValue (bgo#761592).
  + Fix marshaling or GError from Python to C from function calls
    (bgo#685197).
  + Error handling/reporting fixes (bgo#751956).
  + Fix crash due to GVariant implemented as PyGBoxed not
    PyGIStruct (bgo#751956).
  + Fix crash with GValueArray stored in GValue (bgo#754359).
* Sun Feb 21 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + tests:
  - Set the active style context state before retrieving values.
  - Fix crash with empty drag source icon names (bgo#762392).
  + Try to import GdkX11 in Gdk overrides (bgo#673396).
  + Fix import warnings pointing to the wrong code with CPython
    3.3/3.5 (bgo#757184).
* Wed Nov 25 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + tests: Fix failure due to new GTK+ warning regarding
    size_allocate().
  + Fix build warnings regarding _POSIX_C_SOURCE redefinition.
  + Drop -std=c90 for now.
- Changes from version 3.19.1:
  + Use a named tuple for returning multiple values (bgo#727374).
  + enum/flags: use gir info for type names and __repr__ instead of
    the gtype name (bgo#657915).
  + Improve and unify __repr__ format for PyGObject, PyGBoxed and
    PyGIStruct (bgo#657915).
  + Don't leak internal RepositoryError on import (bgo#756033).
  + Import dependencies when importing typelibs from gi.repository
    (bgo#656314).
  + Don't import inspect at module level.
  + invoke state: add a free memory cache for PyGIInvokeArgState
    (bgo#750658).
  + invoke/closure: reduce g_slice_alloc usage (bgo#750658).
  + Bump g-i dependency to latest stable.
  + Avoid calling g_slist_length() during invoke.
  + Simplify closure_convert_arguments().
  + Remove a level of indentation in convert_ffi_arguments().
  + Prevent passing the user data multiple times to callbacks
    (bgo#750347).
  + Support throwing exceptions in closures (bgo#710671).
* Sat Oct 24 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Reroll of tarball to correct the previous one.
- Changes from version 3.18.1:
  + Fix Gdk.rectangle_intersect/rectangle_union missing with GTK+
    3.18 (bgo#756364).
  + pep8: ignore new errors reported by pep8 1.6.
  + Don't emit require_version warning if namespace was loaded
    previously using g_irepository_require (bgo#754491).
* Wed Oct 21 2015 toddrme2178@gmail.com
- Explicitly define python build version.
  Fixes incorrect autodetection in some situations
  (such as devel:languages:python3 right now).
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Stable release, no changes.
* Thu Aug 20 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Allow passing unicode lists to GStrv properties on Python 2
    (bgo#744745).
  + Avoid a silent long to int truncation (bgo#749698).
  + Handle gtype marshalling (bgo#749696).
  + pygi-foreign-cairo.c: fix include for py3cairo.h (bgo#746742).
  + tests: Silence various error messages and warnings
    (bgo#751156).
  + Fix test regression when xdg-user-dirs is not installed
    (bgo#751299).
  + Explicitly check if an override exists instead of ImportError
    (bgo#749532).
* Mon Jun 15 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Add gi.PyGIWarning used when import version is not specified
    (bgo#727379).
  + Remove Gdk.Rectangle alias with newer gobject-introspection and
    GTK+ (bgo#749625).
  + Field setters: Remove unneeded type/range checks and unused
    code (bgo#746985).
  + pygi-argument: Remove unused imports/includes (bgo#746985).
  + Improve test coverage for field setters/getters (bgo#746985).
* Mon Jun 15 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + overrides: Provide _overrides_module attribute (bgo#736678).
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + overrides: Conditionalize touch override support in Gdk
    (bgo#747717).
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Stable release, no changes since 3.15.91.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Add GLib.MINFLOAT etc. and mark GObject.G_MINFLOAT etc.
    deprecated (bgo#743514).
  + Emit PyGIDeprecationWarning when accessing deprecated override
    attributes (bgo#743514).
  + Add namespace and container name to all warnings/error messages
    (bgo#743468).
  + Avoid duping filenames when marshalling from Python to C
    (bgo#744719).
  + test:
  - Don't use deprecated override attributes (bgo#743514).
  - Add test for GIRepository.UnionInfo.get_size() (bgo#745362).
* Sat Feb 21 2015 dimstar@opensuse.org
- Update to version 3.15.0:
  + Avoid copying bytearrays from Python to C when transfer nothing
    (bgo#743278).
  + Allows passing arguments to opaque Boxed types (bgo#743214).
  + Emit ImportWarning when gi.require_version() is not used
    (bgo#727379).
  + Refactor overrides import/modules (bgo#736678).
  + Replace statically bound GLib.Variant.new_tuple() with GI
    (bgo#735199).
  + overrides: Add Gdk.EventTouch union discrimination
    (bgo#736380).
  + PyGObjectFlags: Remove a trailing comma on the enum.
  + Remove redefinitions of function and vfunc cache typedefs.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Stable release, no changes since version 3.13.92.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + tests:
  - Add test for Gio.Application.add_main_option().
  - Split up various test cases (bgo#735193).
  - Fix invalid read error in argument cleanup code.
  - Fix memory management problems with struct arguments to
    signals (bgo#736175).
* Tue Sep  2 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + docs: Fix return types in auto-generated doc strings.
  + Special case signal output arguments which are structs as
    pass-by-reference (bgo#735486).
  + Ignore closure callbacks when Python is not initialized
    (bgo#722562).
  + Change boxed init with args to warn instead of raise
    (bgo#727810).
  + Fix crash in GList/GSList marshaling error handling path
    (bgo#735201).
  + Fix reference counting problems with GLib.Variant.new_tuple()
    (bgo##735166).
  + Skip marshalling NULL output arguments in Python closures
    (bgo#735090).
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Support array lengths on struct fields (bgo#688792).
  + Fast path Python property get access (bgo#723872).
  + Unify accessing properties through props and get_property()
    (bgo#726999).
  + Refactor boxed wrapper memory management strategy (bgo#726999).
  + Replace GObject.signal_query with introspected version
    (bgo#688792).
  + Fix memory leak with unboxed caller allocated structs.
  + tests: Add failing tests for GObject sub-class doc-strings
    (bgo#731452).
  + Don't mask GObject sub-class doc strings in meta-class
    (bgo#731452).
* Fri Aug 15 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Marshaling cache refactor and cache usage in vfuncs
    (bgo#727004).
  + Fix array argument out and inout marshaling from vfuncs
    (bgo#702508).
  + Cleanup input args when marshaling in closures (bgo#727004).
  + Add deprecation warning for connect_object() with non-GObject
    argument (bgo#688064).
  + Add Python implementation of Object.connect_data()
    (bgo#701843).
  + Add GClosure marshaling cleanup (bgo#695128).
  + Fix GCallback Python wrapper leak (bgo#695130).
  + tests: Add failing test for marshaling an array of GValues
    through signals (bgo#669496).
  + Add protection against attempts at importing static bindings
    (bgo#709183).
  + Update and deprecate gi.overrides.keysyms (bgo#721295).
  + Generate .dll libraries on windows (bgo#734288).
  + Windows build fixes: bgo#734284, bgo#734289, bgo#734286,
    bgo#734287.
* Fri Jul 18 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + demos: Cleanup CSS accordion demo to use a loop for adding
    buttons.
  + refactor: Move builder connection utilities outside of Builder
    class (bgo#701843).
  + tests: Move TestSignals from test_everything into test_signal
    (bg#701843).
- Changes from version 3.13.2:
  + Python 3.4 make check fixes (bgo#730411).
  + overrides: Add Gtk.Container.child_get/set overrides
    (bgo#685076).
  + overrides: Make value argument to Widget.style_get_property
    optional (bgo#685076).
  + overrides: Make value argument to Container.child_get_property
    optional (bgo#685076).
  + Add GTypeClass methods as Python GObject class methods
    (bgo#685218).
  + Add marshalling coercion for Python classes and instances to
    GTypeClass (bgo#685218).
  + Replace direct parent class call by super() (bgo#729970).
  + Add cairo marshaling support for non-introspected signals
    (bgo#694604).
  + [New API] Add gi.require_foreign  (bgo#707735).
  + Initialize the foreign API at PyGI load time (bgo#694604).
  + Move pygi foreign API into pygi-foreign-api.h (bgo#694604).
  + Unify GLib.GError and GLib.Error (bgo#712519).
  + PEP8 fixes.
- Changes from version 3.13.1:
  + Raise TypeError if arguments are passed to Boxed.__init__
    (bgo#727810).
  + Gdk.Event: Override __setattr__ to set fields based on the
    event type (bgo#727810).
  + Gdk.Event: Include GdkEventType in __repr__ (bgo#727810).
  + Fix crash with type checking for GObject arguments
    (bgo#727604).
  + Do not leak info of destroy notify.
  + Ignore GValueArray deprecations.
  + Raise ImportError when importing modules not found in
    repository (bgo#726877).
  + tests: Rename test_overrides to test_import_machinery
    (bgo#726877).
* Thu Jul 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + PEP8 fixes.
  + Python 3.4 make check fixes (bgo#730411).
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Fix crash with type checking invalid GObject arguments
    (bgo#727604).
  + Do not leak info of destroy notify.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + No changes since version 3.11.92.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Build system: Remove option to build without libffi.
  + Docs: Standardize Python doc strings.
  + Fix reference leaks with (transfer full) foreign struct returns
    (bgo#726206).
- Rebase pycompile-searchpath.patch.
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Use ffi_call directly instead of g_callable_info_invoke
    (bgo##723642).
  + configure.ac: Use -std=c90 and error on
    declaration-after-statement.
  + Fix Build on Visual Studio (bgo##725122).
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Use GObject type checking for instance arguments (bgo#724009).
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Cache refactoring: Move all cache marshalers into files based
    on type (bgo#709700).
  + Merge static PyGLib and PyGObject modules into PyGI
    (bgo#712197).
  + Add test for callback user data arguments with following
    arguments (bgo#722104).
  + build:
  - Add --without-common configure option for package maintainers
    (bgo#721646).
  - Set PLATFORM_VERSION again to 3.0.
  + demo: Add TreeModel interface implementation demonstration.
  + tests:
  - Run PyFlakes and PEP8 only on SUBDIRS.
  - Add test for an owned boxed struct passed in a callback
    (bgo#722899).
- Pass without-common to configure when building for pythonn: this
  replaces the old method of deleting files during the install
  phase.
- Drop libpyglib-gi-2_0-python%%{local_lib_ver} subpackage: the
  static PyGlib has been merged into PyGI.
- No longer provide a -devel package when building for python3: the
  resulting package after cleanup would be empty.
- Obsolete/provide python3-gobject-devel by python-gobject-devel to
  ease upgrades.
- Require python3-gobject from python-gobject-devel (this was
  brought in before by requiring python3-gobject-devel, which in
  turn pulled in python3-gobject. With the removal of the python3
  based -devel package (see above), we need to require the python3
  variant by ourself.
- Rebase pycompile-searchpath.patch.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + overrides: Fix __repr__ for various Gdk structs.
  + Add enum and flags member methods (bgo#693099).
  + python.m4: g/c JD_PYTHON_CHECK_VERSION (bgo#721662).
  + Support union creation with PyGIStruct.a
  + docs: Fix array length argument skipping with preceding out
    arguments.
  + Updated docs (bgo#708060, bgo#697356, bgo#697356).
  + gtk-demo: Add CSS demos (bgo#719722).
  + build: Avoid clash between gi/types.py and stdlib (bgo#721025).
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + Replace usage of PyGIBoxed_Type with PyGIStruct_Type
    (bgo#581525).
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + gkt-demo: Change main info/source notebook into a GtkStack.
  + Add deprecation warnings and cleanup class initializer
    overrides (bgo#705810).
  + Fix dir method for static GParamSpec in Python 3.
  + Remove overzealous argument checking for callback userdata
    (bgo#711173).
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Fix toggleref safety problems by always enabling the GIL
    (bgo#709223).
  + Add consistent GLib.MainLoop SIGINT cleanup (bgo#710978).
  + docs: Add a keyword value of None for allow-none annotations
    (bgo#640812).
  + Remove overrides for supporting pre-3.10 GObject signal
    functions.
  + Add threads_init back as a requirement for non-Python threaded
    repos (bgo#710447).
  + Add dir method to GObject props accessor (bgo#705754).
  + Remove PyGObjectWeakRef now that g_binding_unbind exists
    (bgo#699571).
  + Fix lots of memory leaks leaks (bgo#693402).
  + Add support for variable user data arguments (bgo#640812).
  + Bump glib and g-i dependencies to latest stable.
  + Expose all GI enum and flags types (bgo#709008).
  + Add support for default arguments annotated with allow-none
    (bgo#640812).
  + Refactor argument cache handling (bgo#640812).
  + Remove support for allowing PyObjects as void pointers
    (bgo#688081).
* Thu Feb 13 2014 jmatejek@suse.com
- Add pycompile-searchpath.patch: clean up search path in
  py-compile script (fixes build on py3.4).
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Fix thread safety problems by always enabling the GIL
    (bgo#709223, bgo#710447).
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + bgo#709926: Fix TypeError when setting drag target_list to
    None.
  + bgo#709223: Use qdata for wrapper retrieval in toggle reference
    notifications.
  + bgo#709397: Fix memory leak for caller allocated GValue out
    arguments.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Fix test_gi.TestProjectVersion.test_version_str().
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + bgo#703873: Fix union argument regression when marshaling from
    python.
  + bgo#707904: Fix GLib.Source sub-classing with initializer args.
  + Copy __doc__ when wrapping function.
* Thu Sep 12 2013 dimstar@opensuse.org
- Drop pygtkcompat subpackage: the compatibility layer is no longer
  used and causes adverse side-effects (like pulling in Gtk2,
  which is not corectly introspectable, causing all kind of other
  weird issues).
* Mon Sep  2 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Fix GObject signal methods to work with new annotations
    (bgo#707280).
  + Fix build on C89 Compilers (bgo#707264).
  + Change boxed type checking in marshaling to use __gtype__
    attribute bgo#707140).
  + Use G_IS_VALUE for checking return values in closure marshaling
    (bgo#707170).
  + Fix PEP-8 errors in propertyhelper.py (bgo#706319).
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + bgo#705451: Create GLib.Pid in the same way on python 2 and 3.
  + bgo#705451: Use PyLong_Type.tp_new for GLib.Pid.
  + bgo#705533: Add accumulator and accu_data arguments to
    GObject.Signal decorator.
  + bgo#705530: Pass return values through the GObject.Signal.emit
    wrapper.
* Mon Jul 29 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Speed up MRO calculation (bgo#703829).
  + Bugs fixed: bgo#705064, bgo#705057, bgo#640812, bgo#698547,
    bgo#704037, bgo#688081, bgo#693405, bgo#688081, bgo#682320,
    bgo#703973, bgo#703960, bgo#688081, bgo#694233, bgo#693994,
    bgo#701058, bgo#702552, bgo#701009, bgo#703456, bgo#702787,
    bgo#702786.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + examples/option.py: Port to GI and Python 3.
  + Fix vfunc info search for classes with multiple inheritance
    (bgo#700092).
  + Fix closure argument conversion for enum and flag in args.
  + Fix marshaling Python to FFI return value for enum and flags.
  + Remove half implemented GC in PyGIBaseInfo, PyGIStruct, and
    PyGIBoxed (bgo#677091).
  + Replace usage of pyg_begin_allow_threads with
    Py_BEGIN_ALLOW_THREADS (bgo#699440).
  + Remove and deprecate API for setting of thread blocking
    functions (bgo#699440).
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Drop support for Python 2.6.
  + Bugs fixed: bgo#698547, bgo#699096, bgo#698829, bgo#685218,
    bgo#685218, bgo#698366, bgo#698444, bgo#698477, bgo#697363,
    bgo#696143, bgo#696646, bgo#697951, bgo#693405, bgo#696648,
    bgo#696646, bgo#696892, bgo#686914, bgo#686795.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + pygi-convert.sh: Add GStreamer rules (bgo#697951).
  + pygi-convert: Add rule for TreeModelFlags.
  + Fix enum and flags marshaling type assumptions.
  + Use g_strdup() consistently (bgo#696650).
  + Fix stack corruption due to incorrect format for argument
    parser (bgo#696892).
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + tests: Fix incorrect assumption when testing pyglib version.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + pygtkcompat: Make gdk.Window.get_geometry return tuple of 5.
  + pygtkcompat: Initialize hint to zero in set_geometry_hints.
  + Remove incorrect bounds check with property helper flags.
  + Bugs fixed: bgo#637832, bgo#696011, bgo#694889, bgo#695420,
    bgo#695420.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91.1:
  + Revert "Drop gi.overrides.overridefunc()" (bgo#695199).
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Fix many memory leaks (bgo#675726, bgo#693402, bgo#691501,
    bgo#510511, bgo#691501, bgo#672224, and several more which are
    detected by our test suite)
  + Dot not clobber original Gdk/Gtk functions with overrides
    (bgo#686835)
  + Optimize GValue.get/set_value by setting GValue.g_type to a
    local (bgo#694857)
  + Run tests with G_SLICE=debug_blocks (bgo#691501)
  + Add override helper for stripping boolean returns (bgo#694431)
  + Drop obsolete pygobject_register_sinkfunc() declaration
    (bgo#639849)
  + Fix marshalling of C arrays with explicit length in signal
    arguments (bgo#662241)
  + Fix signedness, overflow checking, and 32 bit overflow of
    GFlags (bgo#693121)
  + gi/pygi-marshal-from-py.c: Fix build on Visual C++ (bgo#692856)
  + Raise DeprecationWarning on deprecated callables (bgo#665084)
  + pygtkcompat: Add Widget.window, scroll_to_mark, and window
    methods (bgo#694067)
  + pygtkcompat: Add Gtk.Window.set_geometry_hints which accepts
    keyword arguments (bgo#694067)
  + Ship pygobject.doap for autogen.sh (bgo#694591)
  + Fix crashes in various GObject signal handler functions
    (bgo#633927)
  + pygi-closure: Protect the GSList prepend with the GIL
    (bgo#684060)
  + generictreemodel: Fix bad default return type for
    get_column_type.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + overrides:
  - Fix inconsistencies with drag and drop target list API
    (bgo#680640).
  - Add support for iterables besides tuples for TreePath
    creation (bgo#682933).
  + pygtkcompat: Add pygtk compatible GenericTreeModel
    implementation (bgo#682933).
  + Prefix __module__ attribute of function objects with
    gi.repository (bgo#693839).
  + Bugs fixed: bgo#693328, bgo#693618, bgo#687522.
* Tue Feb  5 2013 p.drouand@gmail.com
- Update to version 3.7.5.1:
  + Fix ABI break with pygobject.h from 3.7.5 (bgo#675726).
- Changes from version 3.7.5:
  + Move various signal methods from static bindings to GI
    (bgo#692918)
  + GLib overrides: Support unpacking 'maybe' variants (bgo#693032)
  + Fix ref count leak when creating pygobject wrappers for input
    args (bgo#675726)
  + Prefix names of typeless enums and flags for GType registration
    (bgo#692515)
  + Fix compilation with non-C99 compilers such as Visual C++
    (bgo#692856)
  + gi/overrides/Glib.py: Fix running on Windows/non-Unix
  + Do not immediately initialize Gdk and Gtk on import
    (bgo#692300)
  - Accept inf and NaN as float and double values (bgo#692381)
  - Fix repr() of GLib.Variant
  - Fix gtk-demo for Python 3
  - Define GObject.TYPE_VALUE gtype constant
  * gobject: Go through introspection on property setting
    (bgo#684062)
  * Clean up caller-allocated GValues and their memory
    (bgo#691820)
  - Use GNOME_COMPILE_WARNINGS from gnome-common.
* Mon Jan 14 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Allow setting values through GtkTreeModelFilter (bgo#689624)
  + Support GParamSpec signal arguments from Python (bgo#683099)
  + pygobject_emit(): Fix cleanup on error
  + Add signal emission methods to TreeModel which coerce the path
    argument (bgo#682933)
  + Add override for GValue (bgo#677473)
  + Mark caller-allocated boxed structures as having a slice
    allocated (bgo#699501)
  + pygi-property: Support boxed GSList/GList types (bgo#684059)
  + tests: Add missing backwards compat methods for Python 2.6
    (bgo#691646)
  + Allow setting TreeModel values to None (bgo#684094)
  + Set clean-up handler for marshalled arrays (bgo#691509)
  + Support setting string fields in structs (bgo#678401)
  + Permit plain integers for "gchar" values
  + Allow single byte values for int8 types (bgo#691524)
  + Fix invalid memory access handling errors when registering an
    enum type
  + Fix (out) arguments in callbacks
  + Fix C to Python marshalling of struct pointer arrays
  + Don't let Property.setter() method names define property names
    (bgo#688971)
  + Use g-i stack allocation API (bgo#615982)
  + pyg_value_from_pyobject: support GArray (bgo#690514)
  + Fix obsolete automake macros (bgo#691101)
  + Change dynamic enum and flag gtype creation to use namespaced
    naming (bgo#690455)
  + Fix Gtk.UIManager.add_ui_from_string() override for non-ASCII
    chars (bgo#690329)
  + Don't dup strings before passing them to type registration
    functions (bgo#690532)
  + Fix marshalling of arrays of boxed struct values (bgo#656312)
* Wed Jan  9 2013 dimstar@opensuse.org
- Resolve conflict between python-gobject-devel and
  python3-gobject-devel: only package the .h and .pc file in
  python-gobject-devel, but require python-gobject-devel from this
  package (See bgo#689068 for background). The .pc and .h files are
  python-version agnostic.
- Add supplemnts to auto-install python(3)?-gobject when python(3)?
  and libgirepository-1_0-1 are installed.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Add support for caller-allocated GArray out arguments
    (bgo#690041)
  + [API add] Re-support calling GLib.io_add_watch with an fd or
    Python file
  - pygtkcompat: Work around IndexError on large flags
  - Fix pyg_value_from_pyobject() range check for uint
  - Fix tests to work with g-i 1.34.2
  + Fix wrong refcount for GVariant property defaults (bgo#689267)
  - Fix array arguments on 32 bit architectures
  - Add backwards compatible API for GLib.unix_signal_add_full()
  + Drop MININT64/MAXUINT64 workaround, current g-i gets this right
    now
  - Fix maximum and minimum ranges of TYPE_(U)INT64 properties
    (bgo#688949)
  - Ship pygi-convert.sh in tarballs (bgo#688697)
- Changes from version 3.7.2:
  + API changes:
  - Drop almost all static GLib bindings and replace them with
    proper introspection.
  - Deprecate calling GLib API through the GObject namespace.
    This has always been a misnomer with introspection, and will
    be removed in a later version; for now this throws a
    PyGIDeprecationWarning.
  - Do not bind gobject_get_data() and gobject_set_data().
    (bgo#641944)
  - Deprecate void pointer fields as general PyObject storage.
    (bgo#683599)
  - Add support for GVariant properties
  - Add type checking to GVariant argument assignment
  - Fix marshalling of arrays of struct pointers to Python
    (bgo#678620)
  - Fix Gdk.Atom to have a proper str() and repr() (bgo#678620)
  - Make sure g_value_set_boxed does not cause a buffer overrun
    with GStrvs (bgo#688232)
  - Fix leaks with GValues holding boxed and object types
    (bgo#688137)
  - Add doc strings showing method signatures for gi methods
    (bgo#681967)
  - Set Property instance doc string and blurb to getter doc
    string (bgo#688025)
  - Add GObject.G_MINSSIZE
  - Fix marshalling of GByteArrays
  - Fix marshalling of ssize_t to smaller ints
  - Add get_introspection_module for getting
    un-overridden modules (bgo#686828)
  + Add support for lcov code coverage, and add a lot of missing
    GIMarshallingTests and g-i Regress tests.
  - pygi-convert: remove deprecated GLib → GObject conversions
  - Add support for overriding GObject.Object (bgo#672727)
  - Add --with-python configure option
  + Do not prefer unversioned "python" when configuring, as some
    distros have "python" as Python 3. Use Python 3 by default if
    available. Add --with-python configure option as an alternative
    to setting $PYTHON, which is more discoverable.
  + Fix property lookup in class hierarchy (bgo#686942)
  + Move property and signal creation into _class_init()
    (bgo#686149)
  + Fix duplicate symbols error on OSX
  + Work around wrong 64 bit constants in GLib Gir (bgo#685022)
  + Mark GLib.Source.get_current_time() as deprecated
  + Fix OverflowError in source_remove() (bgo#684526)
  + Updated translations.
* Sat Nov 17 2012 dimstar@opensuse.org
- Update to version 3.7.1:
  + Bump version to 3.7.1; let's follow the real GNOME versioning
    from now on
  + Change install_properties to not use getattr on classes
    (bgo#686559)
  + Move property install function into propertyhelper.py
    (bgo#686559)
  + Fix Signal decorator to not use base class gsignals dict
    (bgo#686496)
  + tests: Consistently use GLib.MainLoop
  + Install the .egg-info files into correct multilib directory
    (bgo#686315)
  + Fix leak with python callables as closure argument (bgo#685598)
  + Gio overrides: Handle setting GSettings enum keys (bgo#685947)
  + tests: Check reading GSettings enums in Gio overrides
  + Fix unsigned values in GArray/GList/GSList/GHash (bgo#685860)
  + _pygi_marshal_from_py_uint64(): Use correct data type in py2.7
    check (bgo#685000)
  + pygobject.c: Don't leak GObjectClass reference (bgo#684062)
  + Fix memory leak in _pygi_argument_to_array() (bgo#685082)
  + GVariant overrides: Support empty tuple arrays (bgo#684928)
  + tests: Fix wrong return type in test_int64_callback()
    (bgo#684700)
  + Fix GValue marshalling of long and unsigned long (bgo#684331)
  + Clean up deprecation message for assigning gpointers to objects
    (bgo#683599)
  + pygi-property: Lookup property in base classes of
    non-introspected types (bgo#684058)
* Fri Nov 16 2012 dimstar@opensuse.org
- Update to version 3.4.2:
  + Fix marshalling of GByteArrays.
  + Fix marshalling of ssize_t to smaller ints.
  + Fix crash with GLib.child_watch_add (bgo#688067).
  + Fix various bugs in GLib.IOChannel.
  + Work around wrong 64 bit constants in GLib Gir (bgo#685022).
  + Fix OverflowError in source_remove() (bgo#684526).
  + Fix Signal decorator to not use base class gsignals dict
    (bgo#686496).
* Thu Oct 18 2012 dimstar@opensuse.org
- Update to version 3.4.1.1:
  + Bump g-i dependency to >= 1.34.1.1
  + Fix leaked vfunc return values (bgo#686140)
  + Install egg-info files in the right dir (bgo#686315)
- Changes from version 3.4.1:
  + Skip Regress tests with --disable-cairo (bgo#685094)
  + Fix leak with python callables as closure argument (bgo#685598)
  + Gio overrides: Handle setting GSettings enum keys (bgo#685947)
  + Fix unsigned values in GArray/GList/GSList/GHash (bgo#685860)
  + _pygi_marshal_from_py_uint64(): Use correct data type in py2.7
    check (bgo#685000)
  + Install an .egg-info file (bgo#680138)
  + pygobject.c: Don't leak GObjectClass reference (bgo#684062)
  + Fix memory leak in _pygi_argument_to_array() (bgo#685082)
  + Fix error messages for out of range numbers (bgo#684314)
  + Kill dbus-daemon after running tests (bgo#685009)
  + GVariant overrides: Support empty tuple arrays (bgo#684928)
  + tests: Fix wrong return type in test_int64_callback()
    (bgo#684700)
  + Fix GValue marshalling of long and unsigned long (bgo#684331)
  + Clean up deprecation message for assigning gpointers to objects
    (bgo#683599)
  + pygi-property: Lookup property in base classes of
    non-introspected types (bgo#684058).
- Drop python-wrong-return.patch: fixed upstream.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.4.0:
  + Bump gobject-introspection dependency to 1.33.14.
- Add python-wrong-return.patch: Fix wrong return type in
  test_int64_callback().
* Thu Sep 20 2012 zaitor@opensuse.org
- Update to version 3.3.92:
  + API additions: Add ObjectInfo.get_abstract method (bgo#675581)
  + Add deprecation warning when setting gpointers to anything
    other than int (bgo#683599)
  + Fix 64bit integer convertion from GValue (bgo#683596)
  + Improve setting pointer fields/arguments to NULL using None
    (bgo#683150)
  + Bump gobject-introspection dependency to >= 1.33.10
  + Fix -uninstalled.pc.in file (bgo#683379)
  + Various test suite additions and improvements.
* Fri Sep  7 2012 vuntz@opensuse.org
- Add pkgconfig(cairo) and pkgconfig(cairo-gobject) BuildRequires:
  new explicit dependencies since 3.3.3.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.3.91:
  + Fix exception test case for Python 2
  + Bump g-i dependency to >= 1.3.9
  + Show proper exception when trying to allocate a disguised struct
    (bgo#639972)
  + Support marshalling GParamSpec signal arguments (bgo#683099)
  + Add test for a signal that returns a GParamSpec (bgo#683265)
  + Fix pygtkcompat's Gtk.TreeView.insert_column_with_attributes()
  + Add override for Gtk.TreeView.insert_column_with_attributes()
    (bgo#679415)
  + Split test_overrides.py (bgo#683188)
  + _pygi_argument_to_object(): Clean up array unmarshalling
  + Fix memory leak in _pygi_argument_to_object() (bgo#682979)
  + Fix setting pointer fields/arguments to NULL using None.
    (bgo#683150)
  + Fix for python 2.6, officially drop support for < 2.6
    (bgo#682422)
  + Allow overrides in other directories than gi itself
    (bgo#680913)
  + Clean up sys.path handling in tests (bgo#680913)
  + Fix dynamic creation of enum and flag gi types for Python 3.3
    (bgo#682323)
  + API additions:
  - Override g_menu_item_set_attribute (bgo#682436)
  - Add Signal class for adding and connecting custom signals.
    (bgo#434924).
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.3.90:
  + Implement marshalling for GParamSpec (bgo#681565)
  + Fix erronous import statements for Python 3.3 (bgo#682051)
  + Do not fail tests if pyflakes or pep8 are not installed
  + Fix PEP-8 whitespace checking and issues in the code
  + Fix unmarshalling of gssize (bgo#680693)
  + Fix various endianess errors (bgo#680692)
  + Gtk overrides: Add TreeModelSort.__init__(self, model)
    (bgo#681477)
  + Convert Gtk.CellRendererState in the pygi-convert script
    (bgo#681596).
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 3.3.5:
  + Fix list marshalling on big-endian machines (bgo#680693)
  + Beautify class/interface type mismatch error messages
  + Skip instead of fail tests which need Pango, Atk, Gdk, Gtk
  + Fix error messages on interface/class type mismatches
  + API additions:
  - pygtkcompat: Add more pixbuf creation functions (bgo#680814)
  - API for checking pygobject's version (bgo#680176)
  + Fix crash when returning (False, None) from
    Gtk.TreeModel.do_get_iter() (bgo#680812)
  + Add test case for Gtk.TextIter.forward_search() (bgo#679415)
  + pygi-info.c: Robustify pointer arithmetic
  + Add set_attributes() override to Gtk.TreeViewColumn
  + Gtk overrides: Add TreePath.__getitem__() (bgo#680353)
  + Bugs fixed: bgo#679939, bgo#680050, bgo#680092, bgo#680257,
    bgo#680259.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 3.3.4:
  + Fix __path__ module attribute
  + m4/python.m4: Update Python version list
  + Bugs fixed: bgo#679999, bgo#679804, bgo#679804, bgo#680004,
    bgo#667244, bgo#679775, bgo#679760, bgo#678914, bgo#679754,
    bgo#675857, bgo#679199, bgo#679336, bgo#670575.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.3.3.1:
  + Do not escape enum and flag names that are Python keywords.
- Changes from version 3.3.3:
  + Remove obsolete release-tag make target
  + Do not do any python calls when GObjects are destroyed after
    the python interpreter has been finalized (bgo#678046)
  + Do not change constructor-only "type" Window property
    (bgo#678510)
  + Escape identifiers which are Python keywords (bgo#676746)
  + Fix code for PEP-8 violations detected by the latest pep8
    checker.
  + Fix crash in GLib.find_program_in_path() (bgo#678119)
  + Revert "Do not bind gobject_get_data() and gobject_set_data()"
    (bgo#641944)
  + GVariant: Raise proper TypeError on invalid tuple input
    (bgo#678317)
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.3.2:
  + foreign: Register cairo.Path and cairo.FontOptions foreign
    structs (bgo#677388)
  + Check types in GBoxed assignments (bgo#676603)
  + Gtk overrides: Add TreeModelRow.get_previous() (bgo#677389)
  + Add missing GObject.TYPE_VARIANT (bgo#677387)
  + Fix boxed type equality (bgo#677249)
  + Fix TestProperties.testBoxed test (bgo#676644)
  + Fix handling of by-reference structs as out parameters
    (bgo#653151)
  + Improved tests.
  + Bugs fixed: bgo#653151, bgo#656554, bgo#672864, bgo#675472,
    bgo#675489, bgo#675489, bgo#675579, bgo#675582, bgo#675892,
    bgo#675911, bgo#676169, bgo#677124.
* Wed May 16 2012 zaitor@opensuse.org
- Update to version 3.3.1:
  + GSettings: allow extra keyword arguments (bgo#675105)
  + pygtkcompat: Correct Userlist module use (bgo#675084)
  + Add release-news make rule
  + Add "make check.nemiver" target
  + Test flags and enums in GHash values (bgo#637466)
  + tests: Activate test_hash_in and apply workaround (bgo#666636)
  + Add special case for Gdk.Atom array entries from Python
    (bgo#661709)
  + test_gdbus: Call GetConnectionUnixProcessID() with correct
    signature (bgo#667954)
  + Add test case for Gtk.ListStore custom sort ) (bgo#674475)
  + GTK overrides: Add missing keyword arguments ) (bgo#660018)
  + Add missing override for TreeModel.iter_previous() (bgo#660018)
  + pygi-convert.py: Drop obsolete drag method conversions
    (bgo#652860)
  + tests: Replace deprecated assertEquals() with assertEqual()
  + Plug tiny leak in constant_info_get_value (bgo#642754)
  + Fix len_arg_index for array arguments (bgo#674271)
  + Support defining GType properties from Python (bgo#674351)
  + Handle GType properties correctly (bgo#674351)
  + Add missing GObject.TYPE_GTYPE
  + Fix test_mainloop.py for Python 3
  + Make callback exception propagation test stricter (bgo#616279)
  + Add context management to freeze_notify() and handler_block().
    (bgo#672324)
  + Add support for GFlags properties (bgo#620943)
  + Wrap GLib.Source.is_destroyed() method (bgo#524719)
  + Fix error message when trying to override a non-GI class
    (bgo#646667)
  + Fix segfault when accessing __grefcount__ before creating the
    GObject (bgo#640434)
  + Do not bind gobject_get_data() and gobject_set_data()
    (bgo#641944)
  + Add test case for multiple GLib.MainLoop instances (bgo#663068)
  + Add a ccallback type which is used to invoke callbacks passed
    to a vfunc (bgo#644926)
  + Regression test: marshalling GValues in GHashTable (bgo#668903)
  + Update .gitignore
  + Fix "distcheck" and tests with out-of-tree builds
  + Add a pep8 check to the makefile (bgo#672627)
  + PEP8 whitespace fixes (bgo#672627)
  + PEP8: Remove trailing ; (bgo#672627)
  + tests: Replace deprecated Python API
  + Fail tests if they use or encounter deprecations
  + Do not run tests in two phases any more
  + test_overrides: Find local gsettings schema with current glib
  + Add GtkComboBoxEntry compatibility (bgo#672589)
  + Correct review comments from Martin (bgo#672578)
  + Correct pyflakes warnings/errors (bgo#672578)
  + Make tests fail on CRITICAL logs, too, and apply to all tests
  + Support marshalling GI_TYPE_TAG_INTERFACE (bgo#668903)
  + Fix warnings on None values in added tree/list store rows
    (bgo#672463)
  + pygtkcompat test: Properly clean up PixbufLoader
- Drop BuildRequires: xz, this comes for free now in the
  buildsystem.
* Tue May 15 2012 vuntz@opensuse.org
- Update to version 3.2.2:
  + Gtk overrides: Implement __delitem__ on TreeModel (bgo#675892)
  + pygtkcompat: Correctly set flags (bgo#675911)
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.2.1:
  + Fix len_arg_index for array arguments
  + Add missing GObject.TYPE_GTYPE
  + GTK+ Overrides:
  - Add missing override for TreeModel.iter_previous()
  - Add missing keyword arguments
  + pygtkcompat:
  - Correct Userlist module use
  - Add GtkComboBoxEntry compatibility
  + GSettings: allow extra keyword arguments
  + pygi-convert.py: Drop obsolete drag method conversions
  + Various other non-code changes
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.2.0:
  + No changes.
* Thu Mar 22 2012 vuntz@opensuse.org
- Update to version 3.1.93:
  + Fix warnings on None values in added tree/list store rows
    (bgo#672463)
  + Support marshalling GI_TYPE_TAG_INTERFACE (bgo#668903)
  + Fixes in tests.
* Wed Mar 21 2012 vuntz@opensuse.org
- Split a python-gobject-pygtkcompat subpackage, for the the
  pygtkcompat module: it is in no way required by default, and it
  requires a lot of introspection bindings.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 3.1.92:
  + Add a PyGTK compatibility layer.
  + Fixes for Python 3.
  + Add default values for paramaters to several constructors and
    methods.
  + Atomic inserts in Gtk.{List,Tree}Store overrides.
  + Fix Gtk.Button constructor to accept use_stock parameter.
  + Correct bad rebase, remove duplicate Window.
  + Add bw-compatible arguments to Gtk.Adjustment.
  + GtkTreePath: make it iterable.
  + Fix double-freeing GValues in arrays.
  + Renamed "property" class to "Property".
  + Fix Python to C marshalling of GValue arrays.
  + Correct the Gtk.Window hierarchy.
  + Renamed getter/setter instance attributes to fget/fset
    respectively.
  + Add Gtk.Arrow/Gtk.Window constructor override.
  + Fix marshalling to/from Python to work on big endian machines.
  + Use gi_cclosure_marshal_generic instead of duplicating it.
  + Override Gtk.TreeView.get_visible_range to fix return.
  + Plug memory leak in _is_union_member.
  + Add and improve tests.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.1.1:
  + Don't use C99 style
  + Drop obsolete g_thread_init()
  + Fix deprecated g_source_get_current_time()
  + Fix deprecated g_value_[gs]et_char()
  + Make pygiconvert.sh correctly convert gtk.gdk.x11_*
  + Fix cset_first typo
  + pygi-convert: Handle Clutter and Cogl
  + Provide access to gpointer struct values
  + Fix GtkBuilder signal connection 'after' logic
  + pygspawn: improve error checking
  + Add and improve tests.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.1.0:
  + Fixed bug where GObject.property did not respect minimum and
    maximum values
  + Handle NULL as a valid case of a char** array
  + Avoid O(n^2) behavior when marshalling lists
  + Connect to first action of a radio group
  + Support functions which return GError
  + Support GHashTable and GError as callback/closure arguments
  + Fix bool(), hash() and __eq__() for GLib.Variant objects
  + Don't issue a deprecation warning for GtkDialog's NO_SEPARATOR
    flag, even when unused
  + Properly distinguish between different integer types for
    properties
  + Distinguish between GArray and GPtrArray when cleaning up
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.0.3:
  + Convert all modifier constants to Gdk.ModifierType
  + Convert all strings to utf-8 encoding when retrieving from
    TreeModel
  + Handle NULL arrays correctly for each array type
  + pygmainloop: avoid lockups if multiple glib.MainLoop exist
  + Properly chain up to the class that implements a given vfunc.
  + Fix array termination and size calculation
  + Fix marshaling of arrays of GVariants
  + pygi-convert:
  - fix for Pango.Alignment
  - fix for Gtk.Orientation
  + Add test for bytearray variants
  + Add tests for calling closures
* Sun Nov  6 2011 badshah400@gmail.com
- Update to version 3.0.2:
  + Add tests for boxed properties
  + Allow GBoxed types as property
  + When converting an object with transfer none, make sure the
    wrapper owns a ref
  + Unit test for checking ref count of object param in signals
  + Gdk overrides: Unbreak for Gdk-2.0
  + Do union member checks for unions that are parameters
* Sat Oct  1 2011 dimstar@opensuse.org
- Update to version 3.0.1:
  + when checking instances union members are same type as parent
  + add a floating flag to pygobjects
  + Revert "Fix refcount bug by not creating python wrapper during
    gobject init stage"
* Fri Sep 30 2011 vuntz@opensuse.org
- Update python3-gobject packaging:
  + Use %%{python3_sitearch} now that it's defined, instead of our
    own custom macro.
  + Change python3 Requires to python(abi) = %%py3_ver, which is
    saner.
  + Do not use wrong libpyglib-gi-2_0-python0 subpackage name for
    the library, but libpyglib-gi-2_0-python3-0, thanks to macros.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.0.0:
  + Fix compilations warnings.
* Fri Sep 16 2011 vuntz@opensuse.org
- Update to version 2.90.4:
  + Various deprecated API that were only needed for the static
    bindings have been removed.
  + Overrides directory variable was taken out of pygobject-3.0.pc
    and moved to the gi._overridesdir attribute to avoid having
    multiple .pc files for each version of Python.
  + Multiple arrays referencing a single length parameter are now
    supported along with flat GValue arrays.
  + Fix refcount crasher bug triggered when using GObject.new.
  + Python 3 now checks instance types again.
  + Documentation is disabled since it isn’t useful yet and
    presents parallel install issues.
  + Demos were fixed up to better reflect the preferred way of
    using PyGObject.
  + Several bug fixes.
  + Build system improvements.
- Drop manual removal of old GTK+ 2 files and documentation that
  conflicted with python-gobject2: fixed upstream.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 2.90.3:
  + Support skip annotation for return values
  + Drop support for old constructor style
  + Drop support for sink functions
  + Reinstate copying of in-line structs in arrays
  + Fix inline struct array handling
  + Add support for __setitem__ to TreeModel and support for slices
    to TreeModelRow
  + Convert ACCEL_* constants into Gtk.AccelFlags
  + Convert TREE_VIEW_DROP_* constants into
    Gtk.TreeViewDropPosition
  + Test GPtrArray regression
  + Fix on demos
* Wed Aug 24 2011 dimstar@opensuse.org
- Fix -devel package files section (pygobject doc is gone)
* Wed Aug 24 2011 dimstar@opensuse.org
- Delete gtk-doc/html/pygobject: The documentation is not
  reflecting the gi-bindings. but the old static ones.
* Mon Aug 22 2011 dimstar@opensuse.org
- Do not package gtk-2.0 subfolder. python-gobject2 provides that.
  python-gobject 3.0 is targetting GTK+ 3.0. See also bgo#657054.
* Thu Aug 18 2011 dimstar@opensuse.org
- Update to version 2.90.2:
  + remove tests that were removed from gi
  + don't calculate item_size using is_pointer
  + Updated signal example to use GObject introspection
  + Updated properties example to use GObject introspection
  + Add override for GLib.Variant.split_signature()
  + [pygi-convert.sh] Handle the import of pygtk and require
    Gtk 3.0
  + Install pygobject.h again.
- Do not provide python-gobject2-devel anymore. It's a package of
  its own.
* Mon Aug 15 2011 dimstar@opensuse.org
- Update to  2.90.1 (3.0 pre-release):
  + New rewritten invoker is twice as fast and easier to extend and
    debug
  + Complete break from static bindings so we may improve the core
    without breaking legacy APIs
  + Better type handling
  + Parallel installable with PyGObject 2.28 for legacy binding
    support (2.28 must be compiled with –disable-introspection)
  + Fixed object array handling
  + Added more overrides for PyGTK API emulation
  + Support for function calling using keyword arguments
  + GObject and GLib symbols can now have overrides
  + All static bit removed or made private
  + GVariants now work from callback returns
- Add xz BuildRequires to be able to decompress the tar.xz source.
- Drop python-gobject-python3.patch: fixed upstream.
- Split out shared library libpygobject-gi-2.0-python.
- No longer obsolete and provide: python-gobject2. We are no longer
  compatible to what python-gobject2 used to provide. For
  compatibility, a python-gobject2 package is being re-instated.
* Fri Jun 17 2011 vuntz@opensuse.org
- Change the source package so we can build both python 2
  (python-gobject) and python 3 (python3-gobject) versions, based
  on the same .spec file:
  + define a build_for_python3 variable to control the behavior
  + use local_py_requires and local_py_sitedir variables, that
    proxy the appropriate values depending on what is being built
  + do not change anything for the python 2 build
  + for the python 3 build:
    . replace python-cairo-devel and python-devel BuildRequires
    with python3-cairo-devel and python3-devel
    . do not keep any Provides/Obsoletes that are related to
    python-gobject2
    . add Conflicts with python-gobject-devel to the devel
    subpackage, as both devel subpackages install the same files
    . export PYTHON=python3 for the build
- Add libffi-devel BuildRequires that will now work, since
  libffi-devel finally comes with a pkg-config file.
- Add python-gobject-python3.patch: patches taken from git, to fix
  build with python 3. Add call to autoreconf, as configure.ac is
  modified.
* Fri Jun 17 2011 vuntz@opensuse.org
- Update to version 2.28.6:
  + Fixes for GVariant.
  + Added __eq__ method for Gdk.Color and Gdk.RGBA
  + Fix symbol names to be locale independent
  + closure: Check the out arg is not null (bgo#651812)
  + Use _gi.Struct to wrap fundamentals
  + Fix two crashes.
* Wed May  4 2011 dimstar@opensuse.org
- Update to version 2.28.4:
  + [gi] Don't create variant twice
  + [gi] Removed hack to avoid using GLib.Variant.new_variant.
  + [gi] Added additional test case for GVariant handling
  + [gi] Added support for GVariant arguments
  + pygi-convert.sh: Make sure the uppercase GObject module is
    imported instead of the lowercase
  + Fix ABI break in old static bindings
  + Fetch size from an enum type
  + dsextras.py: ensure eol characters are preserved when writing
    template files (so \n does not become \r\n)
- Use full URL to tarball as Source: tag.
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 2.28.3:
  + fix a typo when converting objects to strings gvalues
- Changes from version 2.28.2:
  + fixed an ABI break in the static bindings when setting string
    gvalues e.g. passing an int to a Gtk.ListStore column which
    expects a string automatically converts the int to a string
    instead of throwing an error.
- Changes from version 2.28.1:
  + pygi-convert.sh now supports webkit conversions and favors
    using GObject over gobject.
  + Raw closures can now be passed from a signal/vfunc callback to
    a method.
  + Revert linking to the python libs because the python runtime
    statically links it in TreeModel column marshalling is now more
    robust (supports GObject Python Object storing).
  + Gtk.MessageDialog now respects the MessageType
  + You can now send None in for the signature of GDBus messages
    that have no parameters.
  + TreeViewColumn.set_cell_data_func can take None for the func_data
  + Fix syntax error so we can run in Python 2.5
  + Add pickers and menu demos
- Changes from version 2.28.0:
  + fix sinking of floating objects
  + fix leaks when setting properties
  + add basic icon view demo
  + add search entry demo
  + override Gdk.RGBA so you can construct it like
    Gdk.RGBA(1.0, 1.0, 1.0, 1.0).
  + handle unichar gvalues in TreeModels
  + check for _thread module when configuring threading
  + package config file now contains overridesdir variable for 3rd
    party overrides.
  + on windows set bdist_wininst user-access-control property when
    installing.
  + Gtk.stock_lookup return None on failure instead of a success
    value.
  + Python 2.5 fixes
  + Python 3 fixes
* Tue Mar  1 2011 fcrozat@novell.com
- Update to version 2.27.91:
  + Typelibs now loaded at import time instead of lazy loading.
  + Various fixes for GTK+/GDK support via gi.
  + Various other fixes.
- Changes from version 2.27.90:
  + Faster handling of virtual methods when constructing objects
  + Enhanced gdbus and gvarient handling.
  + Enhanced drag and drop support.
  + Enhanced GtkTextBuffer support
  + Enhanced pygi-convert.sh script for automating PyGtk to
    PyGObject Introspection migration.
  + Many introspection fixes.
  + Add/improve various overrides for GTK+.
  + Python 3 fixes.
- Changes from version 2.27.0:
  + Implement richcompare for GIBaseInfo
  + Add a overrides registry so we can reference overrides inside
    the module
  + Add/improve various overrides for GTK+.
  + Many introspection fixes.
  + Python 3 fixes.
  + Various other fixes.
- Remove pygobject-2.26.0-capsule.patch: fixed upstream.
- Change python-gobject2, python-gobject2-cairo and
  python-gobject2-devel Obsoletes to be < instead of <= now that we
  have a new version.
* Wed Feb  9 2011 jmatejek@novell.com
- added patch that switches to new Capsule API, because the deprecated
  PyCObject API will cause a segfault when warnings are exceptions
  (bnc#669802)
* Fri Jan  7 2011 vuntz@opensuse.org
- Rename source package and binary package from python-gobject2 to
  python-gobject: there's no reason to have the trailing 2 here.
- Add appropriate Provides/Obsoletes for migration.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.26.0:
  + A lot of work for introspection support.
  + A lot of work for python3 support.
  + Wrap g_get_system_{config,data}_dirs()
  + Wrap g_uri_list_extract_uris.
  + Add override for GLib.Variant.new_tuple
  + Use Bytes instead of Unicode when reading io
  + Many bug fixes.
  + Fix warnings.
  + Code cleanup.
* Fri Aug 27 2010 vuntz@opensuse.org
- Fix Supplements of python-gobject2-cairo subpackage to reference
  the name of the package providing cairo, instead of
  name-version-arch.
* Sun Aug  8 2010 vuntz@opensuse.org
- Merge doc subpackage in devel subpackage, since the files in
  there are needed when building API docs for other python
  bindings.
* Sun Aug  8 2010 vuntz@opensuse.org
- Update to version 2.21.5:
  + Adjust to API break in GObject-Introspection
  + Override test fixes for new GTK+ annotations
  + Fix up treeiter usage due to caller-allocates annotations in
    gtk+
  + Add  __name__ to DynamicModule class.
  + Do not override GdkRectangle.
  + Add override for TreeModel implementing __len__()
  + Fix warnings
  + Various fixes to demos, and new demos
- Changes from version 2.21.4:
  + Merge PyGI
  + Various fixes to demos, and new demos
- Changes from version 2.21.3:
  + Proper handling of null-ok in virtual methods
  + Fall back to use the floating references API in glib if there
    isn't a sinkfunc defined.
  + Revert "Drop sinkfuncs."
  + [giounix] Make it possible to compile on glib 2.20
  + Release the lock when potentially invoking Python code.
- Changes from version 2.21.2:
  + Drop sinkfuncs.
  + Clear error if we failed the import
  + Added missing , to keyword list of gio.GFile.set_attribute
  + Fix arg conversion in gio.GFile.set_attribute
  + Set constants under python 2.5 or before
  + Doc Extractor: Use replacements that make sense for &...;
    expressions.
  + Setup.py cosmetic tidy
  + Fix crash when importing gio
  + Include pygsource.h
  + codegen/docextract_to_xml.py: One more &...; replacement
    (&nbsp;).
  + codegen/docextract_to_xml.py: Replace some &..; that cause
    errors.
  + codegen/docextract_to_xml.py: Handle C++ multi-line comments.
  + codegen/docextract.py: Stop final section processing on first
    match.
  + Update doc extraction tool to handle GObjectIntrospection
    annotations.
  + bgo#613341 - pygobject tests seem to require pygtk causing a
    circular dependencies problem
  + Don't raise an error in _pygi_import if pygi support is
    disabled
  + Initialize PyGPollFD_Type.fd_obj to NULL
  + Wrap gio.Cancellable.make_pollfd() and add a test
  + Make cancellable an optional parameter in many methods
  + Documentation fixes.
  + Build fixes.
- Add gobject-introspection-devel, python-cairo-devel
  BuildRequires.
- Remove non-existing --enable-pygi configure flag.
- Create a cairo subpackage, for the pygi cairo binding, so that
  cairo is not installed by default with the main package (since
  cairo implies installing X).
- Move /usr/bin/pygobject-codegen-2.0 and /usr/share/pygobject/ to
  devel subpackage.
* Wed Jan  6 2010 vuntz@opensuse.org
- Update to version 2.21.1:
  + Wrap a lot of new API.
  + Make cancellable optional in gio.SocketClient.connect_to_host,
    gio.SocketAddressEnumerator.next,
    gio.Resolver.lookup_by_address, GFile.create_readwrite
  + Deprecate old gio.Drive methods
  + Strip g_ prefix for many other functions
  + Strip g_ prefix from InetAddress functions
  + Fix function name gio.resolver_get_default
  + Register enums and flags in PyGI if needed (bgo#603534)
  + Remove a duplicate entry in gio.defs
  + Fix handling of uchar in pyg_value_from_pyobject
* Sun Dec 20 2009 vuntz@opensuse.org
- Update to version 2.21.0:
  + pygmainloop: fix use of PySignal_WakeUpFD API for nested loops
    (bgo#481569)
  + Add capabilities to import wrappers from pygi
  + Move threads_init() function from 'gobject' to 'glib'
  + Fix wrong minimum checking in float properties (bgo#587637)
  + Wrap new API added in GIO 2.22
  + Fix bad name when rebuilding the unix source module
  + Add the missing limit constants from glibconfig.h (bgo#603244)
  + Suppress warnings about format conversion (bgo#603355)
  + Properly define Connectable as interface type and not object
    type
  + Wrap new API added in GIO-UNIX 2.22
  + Wrap g_find_program_in_path (bgo#598435)
  + Add pygi-external.h into Makefile SOURCES
- Pass --enable-pygi to configure to have introspection support.
* Thu Dec 17 2009 jengelh@medozas.de
- Package documentation as noarch
* Tue Sep 29 2009 vuntz@opensuse.org
- Update to version 2.20.0:
  - Allow to use automake 1.11
  - Specify programming language in .devhelp file
  - Plug reference leak of GSource in pyg_main_loop_init
  - Updated uninstalled.pc file
- Changes from version 2.19.0:
  - Add macros to help with Python list to/from GList/GSList
    conversions.
  - GIO docs practically completed
  - GFileInfo.list_attributes should accept None/NULL
  - Strip out Windows DLL API macros
  - Document that many functions got moved gobject -> glib
  - Allow h2def.py to work when there are tabs or multiple spaces
    after the struct keyword.
  - Fix build when builddir is not the same as srcdir
  - Make gio.Emblem constructor new-style
  - Cleanup GIO overrides to use Python function/method names
  - Make codegen report errors using Python function/method names
  - Fix object type in gio.BufferedInputStream_fill_async
  - Wrap gio.BufferedInputStream.fill_async
  - Add gio.BufferedOutputStream which was forgotten in the types
  - Split overrides for gio.MemoryOutputStream
  - Wrap gio.memory_input_stream_new_from_data
  - Introduces the girepository module from the former PyBank
  - Add API appeared in 2.20 but not marked as such in gio docs
  - Wrap gio.FileOutputStream.query_info_async
  - Wrap gio.FileInputStream.query_async
  - Install executable codegen parts with executing permissions
  - Wrap gio.DataInputStream.read_line_async and read_until_async
  - Fix gio.OutputStream.splice_async
  - Add GIO 2.20 API and update docs
- Remove AutoReqProv: it's default now.
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.18.0:
  + Improve gio docs with some more classes
  + Wrap gio.OutputStream.splice_async()
  + Add Python ver into installed libpyglib name
  + Wrap gio.OutputStream.flush_async()
  + Use 'Requires.private' for libffi in '.pc' files
  + Add wrapper for gio.FileAttributeMatcher
  + Mark relevant glib.IOChannel methods as METH_NOARGS
  + Retire hand-written ChangeLog; autocreate from Git history
  + Wrap gio.InputStream.skip_async()
  + Add in codegen -n --namespace option and the code to remove dll
    API in headers, added documentation
  + Properly mark glib.get_user_special_dir() as a keywords method
* Fri May  1 2009 mboman@suse.de
- Update to version 2.17.0:
  + Write a good part of the docs for gio
  + Wrap g_mount_guess_content_type
    g_mount_guess_content_type_finish
  + Swap first two arguments of gio.File.query_info_async
  + Fix a crash in pyg_type_add_interfaces
  + Remove an empty structure, use sizeof(PyObject)
  + Wrap four g_get_user_*_dir() functions
  + Remove 'ltihooks.py' as using deprecated Python module
  + Code maintenance: add .gitignore files
  + CellRendererPixbuf stock-size property has wrong type
  + Add a doap file after git migration
  + missing dep on libffi in pygobject-2.0.pc
  + g_volume_monitor_tp_new new function, return the singleton
    object
  + Remove a DeprecationWarning under python 2.6
  + several scripts from codegen directory are not distributed
  + g_file_copy_async change argument order to keep it consistent
    with the other methods
  + memory leak in gio.File.copy_async
  + g_file_monitor should accept None for cancellable and set the
    default flag to G_FILE_MONITOR_NONE
  + pyg_notify_free needs to ensure it has GIL before calling
    Py_XDECREF
  + Wrap g_file_set_display_name_async
  + Add a semi-private method to return the option context C object
    from an option context wrapper
  + Converting a negative long Python value to a GUINT64 GValue
    doesn't error out as it should
  + Wrap g_file_set_attributes_async and g_file_set_attributes_finish
  + g_file_query_filesystem_info_async fix a typo
  + Wrap g_file_query_filesystem_info_async
  + Add missing g_file_query_filesystem_info_async and
    g_file_query_filesystem_info_finish
  + Wrap g_file_eject_mountable
  + g_file_copy callback cannot be optional
  + Swap various kwargs names to reflect the code
  + Update the address of the FSF
  + Add g_volume_should_automount
  + Wrap g_drive_enumerate_identifiers and
    g_volume_enumerate_identifiers
  + Add a couple of convinence functions to convert from/to a
    python list and an array of strings
  + Allow setting pytype wrapper class
  + Wrap g_file_enumerator_close_async
* Sun Feb 22 2009 vuntz@novell.com
- Update to version 2.16.1:
  + Apply the patch provided by Cygwin Ports maintainer
    (bgo#564018)
  + Bad -I ordering can break build, patch from (bgo#566737)
  + Fix keyword list to be in sync with positional arguments
    (bgo#566744)
  + Add a comment explaining why the two for loops for registering
    interfaces
  + Huge cleanup of GIO overrides (bgo#566706)
  + gtk.Buildable interface method override is not recognized
    (bgo#566571)
  + Do not escape the ampersand "&" in entity references. Replace
    some unusual entity references in the output with their literal
    values. (bgo#568485)
  + gio.InputStream.read_async can cause memory corruption.
    (bgo#567792)
  + Inconsistent use of tabs and spaces in pygtk.py (bgo#569350)
  + Huge fix of memory leaks in GIO (bgo#568427)
  + non-async functions don't release python locks before calling
    blocking C functions (bgo#556250)
  + Change comment to avoid false positives when grep'ing for
    deprecated gtk functions
  + ltihooks.py updating license header from GPL to LGPL
- Remove gtk-doc BuildRequires.
- Use %%makeinstall
- Stop using pygobject-acinclude.m4: it's not needed anymore, it
  seems.
- Use fdupes.
- Move /usr/lib/libpyglib-2.0.so to devel package.
- Add post/postun with ldconfig call.
* Mon Jan  5 2009 mboman@suse.de
- Update to version 2.16.0:
  + gobject.timeout_add_seconds() not found in docs (bgo#547119)
  + _wrap_g_output_stream_write_async not adding a reference to the
    buffer passed (bgo#564102)
  + gio.VolumeMonitor segfaults (bgo#555613)
  + Test if `domain' is not-null before using it to avoids segfaults
    (bgo#561826)
  + g_output_stream_write_all use gsize instead of gssize
  + add __repr__ to gio.Drive, gio.Mount and gio.Volume (bgo#530935)
  + Missing AC_CONFIG_MACRO_DIR([m4]) (bgo#551227)
  + Make codegen not import when corresponding argument types are not
    registered (bgo#551056)
  + Fix typos breaking compilation (bgo#551212)
  + GFile load_contents methods chop data at first \0 (bgo#551059)
* Thu Sep  4 2008 mboman@novell.com
- Update to version 2.15.4:
  + Too many changes and fixes to list. Please see NEWS for full details.
* Mon Jun 30 2008 maw@suse.de
- Update to version 2.14.2:
  + Allow gobject.property work with subclasses (bgo#523352)
  + Unbreak Source.prepare (bgo#523075)
  + Never override customly set 'tp_new' and 'tp_alloc'
  + Don't link against libffi if we cannot find libffi on the
    system (bgo#496006)
  + Dist .m4 files (bgo#496011)
  + Don't return NULL after warning of enum comparsion
    (bgo#519631).
* Thu Apr  3 2008 hpj@suse.de
- Upgraded to version 2.14.1:
  * Avoid wakeups when using Python trunk.
  * Add an uninstalled.pc.
* Thu Sep 20 2007 sbrabec@suse.cz
- Updated to version 2.14.0:
  * Fix a Python 2.6 deprecation warning
  * Wrap g_timeout_add_seconds, when compiling with glib 2.14
  * Always fully initialize the PyGObject
  * Fix compilation in Solaris, again
  * Fix check for default value in boolean type
  * Fix new style properties with subclasses
  * Docs generation fixes
* Tue Jan  9 2007 sbrabec@suse.cz
- Splitted python-gobject2-doc from python-gobject2-devel.
* Mon Jan  8 2007 cthiel@suse.de
- update to version 2.12.3
  * distutils build fixes
  * documentation updates
  * gobject.handler_block_by_func and friends now accept methods
  * avoid truncating of gparamspec
  * set __module__ on gobject derived types
  * Ensure exceptions are raised on errors in gobject.OptionGroup
* Mon Nov 27 2006 sbrabec@suse.cz
- Preamble typo fix.
* Sat Oct 21 2006 cthiel@suse.de
- update to version 2.12.2
  * Make PyGObject 64-bit safe for Python 2.5
  * All headers are now LGPL and not GPL
  * Remove a couple of GCC warnings
  * Revive distutils support
  * Emission hook reference count bugfix
  * MSVC/ANSI C compilation fix
  * Bump Ctrl-C timeout handler from 100ms to 1000
* Sun Oct  1 2006 cthiel@suse.de
- update to version 2.12.1
  * Corrected version check
- changes from 2.11.4 to 2.12.0
  * Install the html files even when using --disable-docs
- changes from 2.11.3 to 2.11.4
  * Include pre-generated html docs in the tarball
  * Fix bug in do_set_property called from constructor
  * Fix type registration involving interfaces with signals and/or properties
- changes from 2.11.2 to 2.11.3
  * Documentation updates
  * Documentation build fixes
  * PyGObject can now be compiled using a C++ compiler
  * Type registration bug fix
* Thu Aug 10 2006 cthiel@suse.de
- initial package (version 2.11.2)
